=====================
Computer Battle Games
=====================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/a/semantic.co.uk/file/d/0Bxv0SsvibDMTVUExUjFhTURCSU0/view>`__



.. toctree::
   :maxdepth: 1

   robot_missile/index
   the_vital_message/index
   shootout/index
   desert_tank_battle/index
   robot_invaders/index
   secret_weapon/index
   escape/index
   pirate_dogfight/index
   supersonic_bomber/index
   iceberg/index
   the_wall/index
   missile/index

